@@ -20,8 +20,6 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
-echo "---- in preprocessing ----"
-echo "---- preprocessing done----"
 </preinstall>
 
 <install_package_names>
@@ -32,7 +30,7 @@ libreoffice-math
 libreoffice-writer
 libreoffice-l10n-fr
 libreoffice-help-fr
-libreoffice-gtk
+libreoffice-gtk2
 </install_package_names>
 
 <postinstall>
@@ -47,7 +45,7 @@ libreoffice-math
 libreoffice-writer
 libreoffice-l10n-fr
 libreoffice-help-fr
-libreoffice-gtk
+libreoffice-gtk2
 </uninstall_package_names>
 
 </app>
