@@ -17,12 +17,12 @@ Latest Slimjet Browser (run again for updates)
 64
 </installable>
 
-<screenshot>none</screenshot>
+<screenshot>https://www.slimjet.com/en/images/newtab.jpg</screenshot>
 
 <preinstall>
-x-terminal-emulator -e wget http://www.slimjet.com/release/slimjet_amd64.deb
-x-terminal-emulator -e dpkg -i slimjet*.deb
-x-terminal-emulator -e apt-get -f install
+wget http://www.slimjet.com/release/slimjet_amd64.deb
+dpkg -i slimjet*.deb
+apt-get -f install
 </preinstall>
 
 <install_package_names>
@@ -38,4 +38,4 @@ rm slimjet*.deb
 <uninstall_package_names>
 slimjet
 </uninstall_package_names>
-</app>
\ No newline at end of file
+</app>
